aboutsummaryrefslogtreecommitdiffstats
path: root/camel/providers/mbox/camel-mbox-summary.h
diff options
context:
space:
mode:
Diffstat (limited to 'camel/providers/mbox/camel-mbox-summary.h')
-rw-r--r--camel/providers/mbox/camel-mbox-summary.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/camel/providers/mbox/camel-mbox-summary.h b/camel/providers/mbox/camel-mbox-summary.h
index 6d98fd051d..ad7af33e91 100644
--- a/camel/providers/mbox/camel-mbox-summary.h
+++ b/camel/providers/mbox/camel-mbox-summary.h
@@ -35,8 +35,7 @@ typedef struct _CamelMboxSummaryClass CamelMboxSummaryClass;
/* extra summary flags */
enum {
- CAMEL_MESSAGE_FOLDER_NOXEV = 1<<16,
-/* CAMEL_MESSAGE_FOLDER_FLAGGED = 1<<17,*/
+ CAMEL_MESSAGE_FOLDER_NOXEV = 1<<17,
};
typedef struct _CamelMboxMessageContentInfo {
@@ -72,7 +71,7 @@ CamelMboxSummary *camel_mbox_summary_new (const char *filename, const char
int camel_mbox_summary_load(CamelMboxSummary *mbs, int forceindex);
/* incremental update */
int camel_mbox_summary_update(CamelMboxSummary *mbs, off_t offset);
-/* perform a folder expunge */
-int camel_mbox_summary_expunge(CamelMboxSummary *mbs);
+/* perform a folder sync or expunge, if needed */
+int camel_mbox_summary_sync (CamelMboxSummary *mbs, gboolean expunge);
#endif /* ! _CAMEL_MBOX_SUMMARY_H */